@@ -11,6 +11,10 @@
 #define WINHEIGHT       400
 #define RADIUS          150
 
+#ifndef EXAMPLES_DATADIR
+#define EXAMPLES_DATADIR "."
+#endif
+
 typedef struct SuperOH
 {
   ClutterActor *stage;
@@ -90,11 +94,12 @@ static void
 clickity (GtkButton *button,
           gpointer   stack)
 {
-	if (g_strcmp0 (gtk_stack_get_visible_child_name (GTK_STACK (stack)), "label") == 0)
-		gtk_stack_set_visible_child_name (GTK_STACK (stack), "clutter");
-	else
-		gtk_stack_set_visible_child_name (GTK_STACK (stack), "label");
-        fade = !fade;
+  if (g_strcmp0 (gtk_stack_get_visible_child_name (GTK_STACK (stack)), "label") == 0)
+    gtk_stack_set_visible_child_name (GTK_STACK (stack), "clutter");
+  else
+    gtk_stack_set_visible_child_name (GTK_STACK (stack), "label");
+
+  fade = !fade;
 }
 
 static void
@@ -145,7 +150,7 @@ main (int argc, char *argv[])
   /* calling gtk_clutter_init* multiple times should be safe */
   g_assert (gtk_clutter_init (NULL, NULL) == CLUTTER_INIT_SUCCESS);
 
-  pixbuf = gdk_pixbuf_new_from_file ("redhand.png", NULL);
+  pixbuf = gdk_pixbuf_new_from_file (EXAMPLES_DATADIR G_DIR_SEPARATOR_S "redhand.png", NULL);
 
   if (!pixbuf)
     g_error("pixbuf load failed");
@@ -169,6 +174,7 @@ main (int argc, char *argv[])
 
   clutter = gtk_clutter_embed_new ();
   gtk_stack_add_named (GTK_STACK (stack), clutter, "clutter");
+  gtk_widget_realize (clutter);
 
   stage = gtk_clutter_embed_get_stage (GTK_CLUTTER_EMBED (clutter));
   clutter_actor_set_background_color (stage, CLUTTER_COLOR_LightSkyBlue);
@@ -182,17 +188,14 @@ main (int argc, char *argv[])
   gtk_container_add (GTK_CONTAINER (vbox), button);
   gtk_widget_set_hexpand (button, TRUE);
 
-  button = gtk_button_new_with_label ("Fullscreen");
-  gtk_button_set_image (GTK_BUTTON (button),
-                        gtk_image_new_from_stock (GTK_STOCK_FULLSCREEN,
-                                                  GTK_ICON_SIZE_BUTTON));
+  button = gtk_button_new_with_mnemonic ("_Fullscreen");
   g_signal_connect (button, "clicked",
                     G_CALLBACK (on_fullscreen),
                     window);
   gtk_container_add (GTK_CONTAINER (vbox), button);
   gtk_widget_set_hexpand (button, TRUE);
 
-  button = gtk_button_new_from_stock (GTK_STOCK_QUIT);
+  button = gtk_button_new_with_mnemonic ("_Quit");
   g_signal_connect_swapped (button, "clicked",
                             G_CALLBACK (gtk_widget_destroy),
                             window);
